ptr

package
v0.3.8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 4, 2026 License: Apache-2.0 Imports: 0 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Deref

func Deref[T any](ptr *T, def T) T

Deref dereferences ptr and returns the value it points to if no nil, or else returns def.

func Equal

func Equal[T comparable](a, b *T) bool

Equal returns true if both arguments are nil or both arguments dereference to the same value.

func To

func To[T any](v T) *T

To returns a pointer to the given value.

Types

This section is empty.

Jump to