Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Deref ¶
func Deref[T any](ptr *T, def T) T
Deref dereferences ptr and returns the value it points to if no nil, or else returns def.
func Equal ¶
func Equal[T comparable](a, b *T) bool
Equal returns true if both arguments are nil or both arguments dereference to the same value.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.